import pytest
from a0 import guess_hangman

@pytest.fixture(scope="session", autouse=True)
def lextest():
    lex = set()
    with open("lexicon.txt", "r") as lf:
        for word in lf:
            lex.add(word.strip())
    return lex

@pytest.mark.parametrize("temp, inp, exp",
     [("____", None, "e"), 
      ("_e__", "e", "t"),
      ("______", {'e', 's', 'r', 'a'}, "t"),
      ("__t___", {'e', 's', 'r', 'a'}, "i"),
      ("__t_on", {'e', 's', 'r', 'a', 'n', 'o', 'i'}, "p"),
      ("_____it__", {'e', 'i', 's', 'n', 't'}, "d"),
      ("_____it__", {'e', 'i', 's', 'n', 't', 'd'}, "r"),
      ("a____ith_", {'e', 'i', 's', 'n', 't', 'd', 'r', 'a', 'h'}, "o")
    ])
def test_hangman(lextest, temp, inp, exp):
    assert guess_hangman(temp, lextest, inp) == exp

def test_imports():
    with open('a0.py', 'rt') as sf:
        for line in sf:
            assert not line.startswith('from'), "No imports allowed"
            if line.startswith('import'):
                assert line.strip() == "import argparse", "No imports allowed"

